@@ -1,4 +1,5 @@
 import threading
+from typing import Tuple, Optional, List
 from .tsocket import TSocket
 from .listener import IListener
 
@@ -9,27 +10,23 @@ from .handle.market_handle import MarketHandle
 
 
 class FinClient(object):
-    __TSocket = None
-    __ChartHandle = None
-    __BaseHandle = None
-    __MarketHandle = None
-    __TradeHandle = None
     __instance_lock = threading.Lock()
 
     def __init__(self):
-        self.__TSocket = TSocket()
-        self.__ChartHandle = ChartHandle(self.__TSocket)
-        self.__BaseHandle = BaseHandle(self.__TSocket)
-        self.__MarketHandle = MarketHandle(self.__TSocket)
-        self.__TradeHandle = TradeHandle(self.__TSocket)
+        self.__TSocket: TSocket = TSocket()
+        self.__ChartHandle: ChartHandle = ChartHandle(self.__TSocket)
+        self.__BaseHandle: BaseHandle = BaseHandle(self.__TSocket)
+        self.__MarketHandle: MarketHandle = MarketHandle(self.__TSocket)
+        self.__TradeHandle: TradeHandle = TradeHandle(self.__TSocket)
 
     def __del__(self):
-        self.__TSocket.close()
-        del self.__TradeHandle
-        del self.__MarketHandle
-        del self.__ChartHandle
-        del self.__BaseHandle
-        del self.__TSocket
+        self.close()
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.close()
 
     @classmethod
     def instance(cls):
@@ -42,6 +39,12 @@ class FinClient(object):
     def set_callback(self, **kwargs):
         if kwargs is None:
             return
+
+        valid_keys = {"on_tick", "on_ohlc", "on_order_update", "on_tradeorder_update", "on_select_rect"}
+        for key in kwargs:
+            if key not in valid_keys:
+                raise ValueError(f"无效的回调参数: {key}，支持的参数为: {valid_keys}")
+
         for key in kwargs:
             if key == "on_tick":
                 self.__MarketHandle.set_callback(on_tick=kwargs[key])
@@ -58,23 +61,32 @@ class FinClient(object):
         self.__MarketHandle.set_listener(listener)
         self.__TradeHandle.set_listener(listener)
 
-    def base_handle(self):
+    def base_handle(self) -> BaseHandle:
         return self.__BaseHandle
 
-    def chart_handle(self):
+    def chart_handle(self) -> ChartHandle:
         return self.__ChartHandle
 
-    def market_handle(self):
+    def market_handle(self) -> MarketHandle:
         return self.__MarketHandle
 
-    def trade_handle(self):
+    def trade_handle(self) -> TradeHandle:
         return self.__TradeHandle
 
-    def connect(self, host: str = None, port: int = None, timeout: int = 30000):
+    def connect(self, host: str = '', port: int = -1, timeout: int = 30000) -> Tuple[bool, str]:
+        if self.__TSocket is None:
+            return (False, '')
+
         return self.__TSocket.connect(host, port, timeout)
 
-    def is_connected(self):
+    def is_connected(self) -> bool:
+        if self.__TSocket is None:
+            return False
+
         return self.__TSocket.is_connected()
 
     def close(self):
+        if self.__TSocket is None:
+            return
+
         self.__TSocket.close()
