@@ -1,13 +1,14 @@
+from typing import Optional
 from ...interface import IData
 from ..market.ohlc_data import OHLCData
 from ...packer.chart.ohlc_value_data_packer import OHLCValueDataPacker
 
 
 class OHLCValueData(IData):
-    def __init__(self, graph_id: str = '', ohlc_data: OHLCData = None):
+    def __init__(self, graph_id: str = '', ohlc_data: Optional[OHLCData] = None):
         super().__init__(OHLCValueDataPacker(self))
         self._GraphID: str = graph_id
-        self._OHLC: OHLCData = ohlc_data
+        self._OHLC: Optional[OHLCData] = ohlc_data
 
     @property
     def GraphID(self):
