@@ -6,7 +6,7 @@ class PlotParamData(IData):
     def __init__(self, plot_index: int = 0, plot_name: str = '', plot_name_color: str = 'white', height: int = 100,
                  is_eqvalue_axis: bool = True, grid_style: int = 2, grid_color: str = "#4f4f4f", back_ground_color: str = "black",
                  border_color: str = "rgb(139,0,0)", border_width: int = 1, show_legend_item: bool = True, grid_x_style: int = 2, grid_x_color: str = '#4f4f4f',
-                 visible: bool = True):
+                 visible: bool = True, show_title_check: bool = True):
         """图块配置参数
 
         Args:
@@ -24,6 +24,7 @@ class PlotParamData(IData):
             grid_x_style (int, optional): 网格垂直线样式.1.实线 2.线状虚线 3.点状虚线 4.点线间隔线 5.点点线间隔线 Defaults to 2.
             grid_x_color (str, optional): 网格垂直线颜色. Defaults to '#4f4f4f'.
             visible(boo,optional): 是否显示，默认 True
+            show_title_check(bool):是否在标题上显示checkbox
         """
         super().__init__(PlotParamDataPacker(self))
         self._PlotIndex: int = plot_index
@@ -40,6 +41,7 @@ class PlotParamData(IData):
         self._GridXColor: str = grid_x_color
         self._GridXStyle: int = grid_x_style
         self._Visible: bool = visible
+        self._ShowTitleCheck: bool = show_title_check
 
     @property
     def PlotIndex(self):
@@ -54,7 +56,7 @@ class PlotParamData(IData):
         return self._PlotName
 
     @PlotName.setter
-    def PlotName(self, value: int):
+    def PlotName(self, value: str):
         self._PlotName = value
 
     @property
@@ -62,7 +64,7 @@ class PlotParamData(IData):
         return self._PlotNameColor
 
     @PlotNameColor.setter
-    def PlotNameColor(self, value: int):
+    def PlotNameColor(self, value: str):
         self._PlotNameColor = value
 
     @property
@@ -145,7 +147,6 @@ class PlotParamData(IData):
     def GridXColor(self, value: str):
         self._GridXColor = value
 
-
     @property
     def Visible(self):
         return self._Visible
@@ -153,3 +154,11 @@ class PlotParamData(IData):
     @Visible.setter
     def Visible(self, value: bool):
         self._Visible = value
+
+    @property
+    def ShowTitleCheck(self):
+        return self._ShowTitleCheck
+
+    @ShowTitleCheck.setter
+    def ShowTitleCheck(self, value: bool):
+        self._ShowTitleCheck = value
