@@ -6,7 +6,8 @@ from .fin_persist_filed_data import FinPersistFiledData
 
 class FinPersistSaveParamData(IData):
     def __init__(self, instrument_id: str = '', period: str = '',
-                 append: bool = False, vacuum: bool = False, base_path: str = ''):
+                 append: bool = False, vacuum: bool = False,
+                 base_path: str = '', type_mark: str = "MarketData"):
         super().__init__(FinPersistSaveParamDataPacker(self))
         self._InstrumentID: str = instrument_id
         self._Period: str = period
@@ -14,6 +15,7 @@ class FinPersistSaveParamData(IData):
         self._Append: bool = append
         self._Vacuum: bool = vacuum
         self._BasePath: str = base_path
+        self._TypeMark: str = type_mark
 
     @property
     def InstrumentID(self):
@@ -60,5 +62,13 @@ class FinPersistSaveParamData(IData):
         return self._BasePath
 
     @BasePath.setter
-    def BasePath(self, value: int):
+    def BasePath(self, value: str):
         self._BasePath = value
+
+    @property
+    def TypeMark(self):
+        return self._TypeMark
+
+    @TypeMark.setter
+    def TypeMark(self, value: str):
+        self._TypeMark = value
