@@ -5,11 +5,11 @@ from .tradeorder_data import TradeOrderData
 
 
 class ReadHistoryTradeOrderParamData(IData):
-    def __init__(self, start_date: str = '', end_date: str = '', data_list: List[TradeOrderData] = []):
+    def __init__(self, start_date: str = '', end_date: str = ''):
         super().__init__(ReadHistoryTradeOrderParamDataPacker(self))
         self._StartDate: str = start_date
         self._EndDate: str = end_date
-        self._DataList: List[TradeOrderData] = data_list
+        self._DataList: List[TradeOrderData] = []
 
     @property
     def StartDate(self):
