@@ -5,11 +5,14 @@ from .instrument_data import InstrumentData
 
 
 class ReadInstrumentParamData(IData):
-    def __init__(self, exchange_id: List[str] = [], instrument_id: List[str] = [], unicode: List[str] = [], base_path=''):
+    def __init__(self, exchange_id: List[str] = [],
+                 instrument_id: List[str] = [],
+                 unicode: List[str] = [], like_unicode: str = ''):
         super().__init__(ReadInstrumentParamDataPacker(self))
         self._ExchangeID: List[str] = exchange_id.copy()
         self._InstrumentID: List[str] = instrument_id.copy()
         self._UniCode: List[str] = unicode.copy()
+        self._LikeUniCode: str = like_unicode
         self._DataList: List[InstrumentData] = []
 
     @property
@@ -34,7 +37,15 @@ class ReadInstrumentParamData(IData):
 
     @UniCode.setter
     def UniCode(self, value: List[str]):
-        self._IUniCode = value
+        self._UniCode = value
+
+    @property
+    def LikeUniCode(self):
+        return self._LikeUniCode
+
+    @LikeUniCode.setter
+    def LikeUniCode(self, value: str):
+        self._LikeUniCode = value
 
     @property
     def DataList(self):
