@@ -8,6 +8,7 @@ class SaveInstrumentParamData(IData):
     def __init__(self):
         super().__init__(SaveInstrumentParamDataPacker(self))
         self._DataList: List[InstrumentData] = []
+        self._BasePath: str = ''
 
     @property
     def DataList(self):
@@ -16,3 +17,11 @@ class SaveInstrumentParamData(IData):
     @DataList.setter
     def DataList(self, value: List[InstrumentData]):
         self._DataList = value
+
+    @property
+    def BasePath(self):
+        return self._BasePath
+
+    @BasePath.setter
+    def BasePath(self, value: str):
+        self._BasePath = value
