@@ -1,26 +1,27 @@
 import threading
 from .tsocket import TSocket
+from typing import Tuple, Optional
 
 from .handle.findata_handle import FinDataHandle
 from .handle.base_handle import BaseHandle
 
 
 class FinDataClient(object):
-    __TSocket = None
-    __FinDataHandle = None
-    __BaseHandle = None
     __instance_lock = threading.Lock()
 
     def __init__(self):
-        self.__TSocket = TSocket()
-        self.__FinDataHandle = FinDataHandle(self.__TSocket)
-        self.__BaseHandle = BaseHandle(self.__TSocket)
+        self.__TSocket: TSocket = TSocket()
+        self.__FinDataHandle: FinDataHandle = FinDataHandle(self.__TSocket)
+        self.__BaseHandle: BaseHandle = BaseHandle(self.__TSocket)
 
     def __del__(self):
-        self.__TSocket.close()
-        del self.__FinDataHandle
-        del self.__BaseHandle
-        del self.__TSocket
+        self.close()
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.close()
 
     @classmethod
     def instance(cls):
@@ -30,13 +31,13 @@ class FinDataClient(object):
                     cls._instance = FinDataClient()
         return cls._instance
 
-    def base_handle(self):
+    def base_handle(self) -> BaseHandle:
         return self.__BaseHandle
 
-    def findata_handle(self):
+    def findata_handle(self) -> FinDataHandle:
         return self.__FinDataHandle
 
-    def connect(self, host: str = None, port: int = None, timeout: int = 30000):
+    def connect(self, host: str = '', port: int = -1, timeout: int = 60000) -> Tuple[bool, str]:
         return self.__TSocket.connect(host, port, timeout)
 
     def is_connected(self):
