@@ -1,10 +1,11 @@
-from typing import Tuple
+from typing import Tuple, Optional, Union
 import msgpack
 import lzma
 import zlib
 import pickle
 import pandas as pd
 import numpy as np
+import json
 
 
 from .req_rsp import ReqRspDict, ReqRsp
@@ -23,12 +24,17 @@ from ..data.market.fin_persist_delete_param_data import FinPersistDeleteParamDat
 from ..data.trade.read_exc_product_param_data import ReadExcProductParamData
 from ..data.trade.read_instrument_param_data import ReadInstrumentParamData
 from ..data.trade.save_instrument_param_data import SaveInstrumentParamData
+from ..data.trade.read_periods_param_data import ReadPeriodsParamData
+from ..data.trade.db_vacuum_param_data import DBVacuumParamData
+from ..data.trade.read_ins_date_range_data import ReadInsDateRangeData
+from ..data.trade.save_financial_param_data import SaveFinancialParamData
+from ..data.trade.read_financial_param_data import ReadFinancialParamData
 
 
 class FinDataHandle():
-    def __init__(self, tsocket: TSocket):
-        self.__TSocket = tsocket
-        self.__TSocket.set_findata_callback(self.__recv_msg)
+    def __init__(self, tsocket: Optional[TSocket] = None):
+        if tsocket is not None:
+            self.set_socket(tsocket)
         self.__ReqID = 0
         self.__ReqRspDict = ReqRspDict()
         self.__ExcProduct_Columns_Types = {"ExchangeID": str, "ProductID": str, "ProductName": str,
@@ -36,7 +42,7 @@ class FinDataHandle():
                                            "MaxMarketOrderVolume": np.int32, "MaxLimitOrderVolume": np.int32,
                                            "Times": {}}
         self.__ExcProductTime_Columns_Types = {"StartTime": str, "EndTime": str, "AddDay": np.int32, "InstrumentStatusKind": np.int32}
-        self.__DB_Columns_Types = {"Day": int, "Mark": str, "Offset": int, "Buffer": bytes}
+        self.__DB_Columns_Types = {"Day": int, "Mark": str, "Offset": int, "Buffer": object}
         self.__Tick_Columns_Types = {"ExchangeID": str, "InstrumentID": str, "TradingDay": str, "ActionDay": str,
                                      "ActionTime": str, "ActionMSec": str, "LastPrice": np.float32,
                                      "LastVolume": np.int32, "BidPrice": np.float32, "BidVolume": np.int32,
@@ -67,6 +73,14 @@ class FinDataHandle():
             "EnsureRatio1": np.float64, "EnsureRatio2": np.float64, "IsCloseToday": bool, "Times": str
         }
 
+        self.__Financial_Columns_Types = {
+            "ID": int, "Day": int, "Type": int, "JsonData": str
+        }
+
+    def set_socket(self, tsocket: TSocket):
+        self.__TSocket = tsocket
+        self.__TSocket.set_findata_callback(self.__recv_msg)
+
     def set_callback(self, **kwargs):
         if kwargs is None:
             return
@@ -88,21 +102,22 @@ class FinDataHandle():
     def get_db_columns_types(self):
         return self.__DB_Columns_Types
 
-    def fin_save_day_list(self, instrument_id: str, df, period: str, **kwargs) -> Tuple[bool, str]:
-        if len(period) == 0:
-            period = "day"
-        return self.__fin_save_list(int(MsgID.FinData_FinSaveDayList.value), self.__Day_Columns_Types.keys(),
-                                    instrument_id, df, period, "TradingDay", **kwargs)
+    def get_financial_columns_types(self):
+        return self.__Financial_Columns_Types
 
-    def fin_read_day_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
-        return self.__fin_read_list(int(MsgID.FinData_FinReadDayList.value), "day",
+    def fin_save_day_list(self, instrument_id: str, df, **kwargs) -> Tuple[bool, str]:
+        return self.__fin_save_list(int(MsgID.FinData_FinSaveDayList.value), self.__Day_Columns_Types.keys(),
+                                    instrument_id, df, "86400", "TradingDay", **kwargs)
+
+    def fin_read_day_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, Union[pd.DataFrame, None]]:
+        return self.__fin_read_list(int(MsgID.FinData_FinReadDayList.value), "86400",
                                     self.__Day_Columns_Types.keys(), params)
 
     def fin_save_ohlc_list(self, instrument_id: str, df, period: str, **kwargs) -> Tuple[bool, str]:
         return self.__fin_save_list(int(MsgID.FinData_FinSaveOHLCList.value), self.__OHLC_Columns_Types.keys(),
                                     instrument_id, df, period, "ActionDay", **kwargs)
 
-    def fin_read_ohlc_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
+    def fin_read_ohlc_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, Union[pd.DataFrame, None]]:
         return self.__fin_read_list(int(MsgID.FinData_FinReadOHLCList.value), "ohlc",
                                     self.__OHLC_Columns_Types.keys(), params)
 
@@ -112,14 +127,47 @@ class FinDataHandle():
         return self.__fin_save_list(int(MsgID.FinData_FinSaveTickList.value), self.__Tick_Columns_Types.keys(),
                                     instrument_id, df, period, "ActionDay", **kwargs)
 
-    def fin_read_tick_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
+    def fin_read_tick_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, Union[pd.DataFrame, None]]:
         return self.__fin_read_list(int(MsgID.FinData_FinReadTickList.value), "tick",
                                     self.__Tick_Columns_Types.keys(), params)
 
-    def fin_read_db_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
+    def fin_read_db_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, Union[pd.DataFrame, None]]:
         return self.__fin_read_db_list(int(MsgID.FinData_FinReadDBList.value), period_name='',
                                        col_keys=self.__DB_Columns_Types.keys(), params=params)
 
+    def fin_save_db_list(self, instrument_id: str, period: str, df, base_path: str, type_mark="MarketData", vacuum=False) -> Tuple[bool, str]:
+        params = FinPersistSaveParamData()
+        params.Append = False
+        params.Period = period
+        params.InstrumentID = instrument_id
+        params.Vacuum = vacuum
+        params.BasePath = base_path
+        params.TypeMark = type_mark
+
+        for row in df.itertuples():
+            fd = FinPersistFiledData()
+            fd.Offset = row.Offset
+            fd.Mark = row.Mark
+            fd.Day = row.Day
+            fd.Buffer = row.Buffer
+            if fd.Offset != len(fd.Buffer):
+                print("数据长度不一致 InsID:%s,Period:%s,Day:%s,Offset:%s,lenBuffer:%s" % (instrument_id, period, fd.Day, fd.Offset, len(fd.Buffer)))
+                raise
+            params.Fileds.append(fd)
+
+        return self.__wait_send_msg(int(MsgID.FinData_FinSaveDayList.value), params)
+
+    def fin_read_periods(self, instrument_id):
+        params = ReadPeriodsParamData()
+        params.InstrumentID = instrument_id
+        return self.wait_read_datas(int(MsgID.FinData_FinReadPeriods.value), params, '', self.__unpack_periods_list)
+
+    def fin_db_vacuum(self, instrument_id, period) -> Tuple[bool, str]:
+        param = DBVacuumParamData()
+        param.InstrumentID = instrument_id
+        param.Period = period
+        return self.__wait_send_msg(int(MsgID.FinData_FinDBVacuum.value), params=param)
+
     def fin_delete_list(self, params: FinPersistDeleteParamData) -> Tuple[bool, str]:
         return self.__wait_send_msg(int(MsgID.FinData_FinDeleteList.value), params)
 
@@ -129,16 +177,58 @@ class FinDataHandle():
     def fin_read_instruments(self, params: ReadInstrumentParamData):
         return self.wait_read_datas(int(MsgID.FinData_FinReadInstrument.value), params, "", self.__unpack_instrument_list)
 
-    def fin_save_instruments(self, df, base_path: str = ''):
+    def fin_delete_instruments(self, params: ReadInstrumentParamData) -> Tuple[bool, str]:
+        return self.__wait_send_msg(int(MsgID.FinData_FinDeleteInstrument.value), params)
+
+    def fin_save_instruments(self, df) -> Tuple[bool, str]:
         if df.columns.to_list() != list(self.__Instrument_Columns_Types.keys()):
-            return [False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), self.__Instrument_Columns_Types.keys())]
+            return (False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), self.__Instrument_Columns_Types.keys()))
 
         params: SaveInstrumentParamData = SaveInstrumentParamData()
         params.DataList = df.values.tolist()
-        params.BasePath = base_path
 
         return self.__wait_send_msg(int(MsgID.FinData_FinSaveInstrument.value), params)
 
+    def fin_save_financials(self, instrument_id: str, df) -> Tuple[bool, str]:
+        if df.columns.to_list() != list(self.__Financial_Columns_Types.keys()):
+            return (False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), self.__Financial_Columns_Types.keys()))
+
+        params: SaveFinancialParamData = SaveFinancialParamData()
+        params.InstrumentID = instrument_id
+        params.DataList = df.values.tolist()
+
+        return self.__wait_send_msg(int(MsgID.FinData_FinSaveFinancial.value), params)
+
+    def fin_read_financials(self, params: ReadFinancialParamData) -> Tuple[bool, str, Union[pd.DataFrame, None]]:
+        return self.wait_read_datas(int(MsgID.FinData_FinReadFinancial.value), params, "", self.__unpack_financial_list)
+
+    def fin_delete_financials(self, params: ReadFinancialParamData) -> Tuple[bool, str]:
+        return self.__wait_send_msg(int(MsgID.FinData_FinDeleteFinancial.value), params)
+
+    def fin_read_ins_date_range(self, params: ReadInsDateRangeData) -> Tuple[bool, str, Union[Tuple[str, str], None]]:
+        return self.wait_read_datas(int(MsgID.FinData_FinReadInsDateRange.value), params, '', self.__unpack_read_ins_date_range_list)
+
+    def __unpack_read_ins_date_range_list(self, reqrsp: ReqRsp) -> Tuple[str, str]:
+        rsp_list = reqrsp.get_rsp_list()
+        ret = ('', '')
+        for r in rsp_list:
+            if len(r.UData) > 0:
+                rspparams = ReadInsDateRangeData()
+                rspparams.un_pack(r.UData)
+                ret = (rspparams.RangeBegin, rspparams.RangeEnd)
+        return ret
+
+    def __unpack_periods_list(self, reqrsp: ReqRsp):
+        os = {}
+        rsp_list = reqrsp.get_rsp_list()
+        for r in rsp_list:
+            if len(r.UData) > 0:
+                rspparams = ReadPeriodsParamData()
+                rspparams.un_pack(r.UData)
+                for k, v in rspparams.DataList.items():
+                    os[k] = v
+        return os
+
     def __unpack_excproduct_list(self, reqrsp: ReqRsp):
         os = list()
         rsp_list = reqrsp.get_rsp_list()
@@ -151,7 +241,23 @@ class FinDataHandle():
                         df_pts = pd.DataFrame(ot[7], columns=list(self.__ExcProductTime_Columns_Types.keys()))
                         ot[7] = df_pts
                     os.append(ot)
-        df = pd.DataFrame(os, columns=self.__ExcProduct_Columns_Types.keys())
+        df = pd.DataFrame(os, columns=list(self.__ExcProduct_Columns_Types.keys()))
+        return df
+
+    def __unpack_financial_list(self, reqrsp: ReqRsp):
+        os = []
+        rsp_list = reqrsp.get_rsp_list()
+        for r in rsp_list:
+            if len(r.UData) > 0:
+                rspparams = ReadFinancialParamData()
+                rspparams.un_pack(r.UData)
+                for ot in rspparams.DataList:
+                    if len(ot) >= 4:  # type: ignore
+                        jsondt = json.loads(ot[3])  # type: ignore
+                        jsondt["InstrumentID"] = rspparams.InstrumentID
+                        jsondt["Type"] = ot[2]  # type: ignore
+                        os.append(jsondt)
+        df = pd.DataFrame(data=os)
         return df
 
     def __unpack_instrument_list(self, reqrsp: ReqRsp):
@@ -163,57 +269,57 @@ class FinDataHandle():
                 rspparams.un_pack(r.UData)
                 for ot in rspparams.DataList:
                     os.append(ot)
-        df = pd.DataFrame(os, columns=self.__Instrument_Columns_Types.keys())
+        df = pd.DataFrame(os, columns=list(self.__Instrument_Columns_Types.keys()))
         return df
 
     def wait_read_datas(self, mid, params: IData, fun_name: str, unpack_func):
         self.__ReqID = self.__ReqID + 1
         msg = MessageData(mid=mid, request_id=self.__ReqID)
         if params is not None:
-            msg.UData = params.pack()
+            msg.UData = params.pack()  # type: ignore
 
         key = '%s_%s' % (mid, self.__ReqID)
         req_rsp = self.__ReqRspDict.new_reqrsp(key, msg)
         if self.__TSocket.send_message(msg) is False:
             self.__ReqRspDict.remove(key)
-            return [False, '发送%s失败' % fun_name, None]
-
-        rsp = req_rsp.wait_last_rsp(10)
-        if rsp is None:
-            self.__ReqRspDict.remove(key)
-            return [False, '获取%s数据超时' % fun_name, None]
-
-        return [True, '%s读取成功' % fun_name, unpack_func(req_rsp)]
-
-    def __fin_save_list(self, mid: int, col_keys, instrument_id, df, period: str, groupby_key: str, **kwargs) -> Tuple[bool, str]:
-        if not isinstance(df, pd.DataFrame):
-            return [False, "df 数据类型格式不是 DataFrame"]
-
-        if df.columns.to_list() != list(col_keys):
-            return [False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), col_keys)]
-
-        b, m, params = self.__create_fin_persists_save_param_data(instrument_id, df, period, groupby_key, **kwargs)
-        if b == False:
-            return [b, m]
-
-        return self.__wait_send_msg(int(mid), params)
-
-    def __fin_read_db_list(self, mid: int, period_name: str, col_keys, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
-        self.__ReqID = self.__ReqID + 1
-        msg = MessageData(mid=mid, request_id=self.__ReqID)
-        if params is not None:
-            msg.UData = params.pack()
-
-        key = '%s_%s' % (mid, self.__ReqID)
-        req_rsp = self.__ReqRspDict.new_reqrsp(key, msg)
-        if self.__TSocket.send_message(msg) is False:
-            self.__ReqRspDict.remove(key)
-            return [False, '发送命令失败', None]
+            return (False, '发送%s失败' % fun_name, None)
 
         rsp = req_rsp.wait_last_rsp(60)
         if rsp is None:
             self.__ReqRspDict.remove(key)
-            return [False, ('获取%s数据超时' % period_name), None]
+            return (False, '获取%s数据超时' % fun_name, None)
+
+        return (True, '%s读取成功' % fun_name, unpack_func(req_rsp))
+
+    def __fin_save_list(self, mid: int, col_keys, instrument_id, df, period: str, groupby_key: str, **kwargs) -> Tuple[bool, str]:
+        if not isinstance(df, pd.DataFrame):
+            return (False, "df 数据类型格式不是 DataFrame")
+
+        if df.columns.to_list() != list(col_keys):
+            return (False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), col_keys))
+
+        b, m, params = self.__create_fin_persists_save_param_data(instrument_id, df, period, groupby_key, **kwargs)
+        if b == False:
+            return (b, m)
+
+        return self.__wait_send_msg(int(mid), params)
+
+    def __fin_read_db_list(self, mid: int, period_name: str, col_keys, params: FinPersistReadParamData) -> Tuple[bool, str, Union[pd.DataFrame, None]]:
+        self.__ReqID = self.__ReqID + 1
+        msg = MessageData(mid=mid, request_id=self.__ReqID)
+        if params is not None:
+            msg.UData = params.pack()  # type: ignore
+
+        key = '%s_%s' % (mid, self.__ReqID)
+        req_rsp = self.__ReqRspDict.new_reqrsp(key, msg)
+        if self.__TSocket.send_message(msg) is False:
+            self.__ReqRspDict.remove(key)
+            return (False, '发送命令失败', None)
+
+        rsp = req_rsp.wait_last_rsp(60)
+        if rsp is None:
+            self.__ReqRspDict.remove(key)
+            return (False, ('获取%s数据超时' % period_name), None)
 
         dflist = []
         rsp_list = req_rsp.get_rsp_list()
@@ -226,29 +332,29 @@ class FinDataHandle():
             for d in rspparams.DataFileds:
                 dflist.append(d.obj_to_tuple())
         df = pd.DataFrame(dflist, columns=col_keys)
-        ret = [rsp.RspSuccess, rsp.RspMsg, df]
+        ret = (rsp.RspSuccess, rsp.RspMsg, df)
 
         self.__ReqRspDict.remove(key)
         return ret
 
-    def __fin_read_list(self, mid: int, period_name: str, col_keys, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
+    def __fin_read_list(self, mid: int, period_name: str, col_keys, params: FinPersistReadParamData) -> Tuple[bool, str, Union[pd.DataFrame, None]]:
         self.__ReqID = self.__ReqID + 1
         msg = MessageData(mid=mid, request_id=self.__ReqID)
         if params is not None:
-            msg.UData = params.pack()
+            msg.UData = params.pack()  # type: ignore
 
         key = '%s_%s' % (mid, self.__ReqID)
         req_rsp = self.__ReqRspDict.new_reqrsp(key, msg)
         if self.__TSocket.send_message(msg) is False:
             self.__ReqRspDict.remove(key)
-            return [False, '发送命令失败', None]
+            return (False, '发送命令失败', None)
 
         rsp = req_rsp.wait_last_rsp(60)
         if rsp is None:
             self.__ReqRspDict.remove(key)
-            return [False, ('获取%s数据超时' % period_name), None]
+            return (False, ('获取%s数据超时' % period_name), None)
 
-        ret = [rsp.RspSuccess, rsp.RspMsg, self.__unpack_fin_persist_read_param_data_to_df(req_rsp, list(col_keys))]
+        ret = (rsp.RspSuccess, rsp.RspMsg, self.__unpack_fin_persist_read_param_data_to_df(req_rsp, list(col_keys)))
 
         self.__ReqRspDict.remove(key)
         return ret
@@ -282,6 +388,7 @@ class FinDataHandle():
                     continue
 
                 decombytes = b''
+                # try:
                 if marks[0] == 'zip':
                     decombytes = zlib.decompress(df.Buffer)
                 elif marks[0] == 'xz':
@@ -291,6 +398,9 @@ class FinDataHandle():
                 elif marks[0] == '0':
                     dflist.append(self.__unpack_stream_buffer(df.Buffer, columns))
                     continue
+                # except Exception as e:
+                #     print("unzib data error %s %s %s,error:%s " % (df.Day, df.Mark, len(df.Buffer), e))
+                #     decombytes = b''
 
                 if len(decombytes) == 0:
                     continue
@@ -299,7 +409,6 @@ class FinDataHandle():
                     dflist.append(pickle.loads(decombytes))
                 else:
                     dflist.append(pd.DataFrame(msgpack.unpackb(decombytes, raw=False), columns=columns))
-
         return dflist
 
     def __create_fin_persists_save_param_data(self, instrument_id: str, df, period: str, groupby_key: str, **kwargs):
@@ -311,7 +420,7 @@ class FinDataHandle():
         compress = 'zip' if 'compress' not in kwargs.keys() else kwargs.get('compress')
         level = -1 if 'level' not in kwargs.keys() else kwargs.get('level')
         pack = 'msgpack' if 'pack' not in kwargs.keys() else kwargs.get('pack')
-        vacuum = True if 'vacuum' not in kwargs.keys() else kwargs.get('vacuum')
+        vacuum = False if 'vacuum' not in kwargs.keys() else kwargs.get('vacuum')
         base_path = '' if 'base_path' not in kwargs.keys()else kwargs.get('base_path')
 
         params: FinPersistSaveParamData = FinPersistSaveParamData()
@@ -319,12 +428,13 @@ class FinDataHandle():
         params.Period = period
         params.InstrumentID = instrument_id
         params.Vacuum = bool(vacuum)
-        params.BasePath = base_path
+        if base_path is not None:
+            params.BasePath = base_path
         groups = df.groupby(groupby_key)
         buffer_sz = 0
         for day, day_list in groups:
             filed = FinPersistFiledData()
-            filed.Day = int(day)
+            filed.Day = int(day)  # type: ignore
             filed.Mark = '%s,%s,%s' % (compress, level, pack)
             pack_buffer = b''
 
@@ -334,9 +444,9 @@ class FinDataHandle():
                 pack_buffer = msgpack.packb(day_list.values.tolist(), use_bin_type=True)
 
             if compress == 'zip':
-                filed.Buffer = zlib.compress(pack_buffer, level=level)
+                filed.Buffer = zlib.compress(pack_buffer, level=level)  # type: ignore
             else:
-                filed.Buffer = lzma.compress(pack_buffer)
+                filed.Buffer = lzma.compress(pack_buffer)  # type: ignore
 
             buffer_sz = buffer_sz + len(filed.Buffer)
             params.Fileds.append(filed)
@@ -344,7 +454,7 @@ class FinDataHandle():
 
     def __recv_msg(self, msg: MessageData):
         key = '%s_%s' % (msg.MID, msg.RequestID)
-        reqrsp: ReqRsp = self.__ReqRspDict.get_reqrsp(key)
+        reqrsp: Optional[ReqRsp] = self.__ReqRspDict.get_reqrsp(key)
         if reqrsp is not None:
             reqrsp.append_rsp(msg)
 
@@ -352,20 +462,20 @@ class FinDataHandle():
         self.__ReqID = self.__ReqID + 1
         msg = MessageData(mid=mid, request_id=self.__ReqID)
         if params is not None:
-            msg.UData = params.pack()
+            msg.UData = params.pack()  # type: ignore
 
         key = '%s_%s' % (mid, self.__ReqID)
 
         req_rsp = self.__ReqRspDict.new_reqrsp(key, msg)
         if self.__TSocket.send_message(msg) is False:
             self.__ReqRspDict.remove(key)
-            return [False, '发送命令失败']
+            return (False, '发送命令失败')
 
         rsp = req_rsp.wait_last_rsp(60)
         if rsp is None:
             self.__ReqRspDict.remove(key)
-            return [False, '发送命令超时']
+            return (False, '发送命令超时')
 
-        ret = [rsp.RspSuccess, rsp.RspMsg]
+        ret = (rsp.RspSuccess, rsp.RspMsg)
         self.__ReqRspDict.remove(key)
         return ret
