@@ -6,8 +6,8 @@ class BaseGraphParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.ID), str(self._obj.Name), int(self._obj.PlotIndex), int(self._obj.ValueAxisID),
-                bool(self._obj.Visible), self._obj.UserData]
+        return (str(self._obj.ID), str(self._obj.Name), int(self._obj.PlotIndex), int(self._obj.ValueAxisID),
+                bool(self._obj.Visible), self._obj.UserData)
 
     def tuple_to_obj(self, t):
         if len(t) >= 6:
