@@ -6,7 +6,7 @@ class GraphValueDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.GraphID), float(self._obj.Key), int(self._obj.MillTimeSpan), float(self._obj.Value)]
+        return (str(self._obj.GraphID), float(self._obj.Key), int(self._obj.MillTimeSpan), float(self._obj.Value))
 
     def tuple_to_obj(self, t):
         if len(t) >= 4:
