@@ -9,7 +9,7 @@ class GraphValueListDataPacker(IPacker):
         gv_list = []
         for o in self._obj.GVList:
             gv_list.append(o.obj_to_tuple())
-        return [gv_list]
+        return tuple([gv_list])
 
     def tuple_to_obj(self, t):
         if len(t) >= 1:
