@@ -6,13 +6,13 @@ class LegendItemParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [int(self._obj.PlotIndex), int(self._obj.Type), int(self._obj.HAlgin),
+        return (int(self._obj.PlotIndex), int(self._obj.Type), int(self._obj.HAlgin),
                 int(self._obj.VAlgin), int(self._obj.ItemMargin),
                 int(self._obj.ItemSpace), int(self._obj.HOffset),
                 int(self._obj.VOffset), int(self._obj.MaxColumns),
                 int(self._obj.BorderWidth), str(self._obj.BorderColor),
                 int(self._obj.BorderRadius), int(self._obj.BackGroundAlpha),
-                str(self._obj.BackGroundColor)]
+                str(self._obj.BackGroundColor))
 
     def tuple_to_obj(self, t):
         if len(t) >= 14:
