@@ -6,7 +6,7 @@ class OHLCValueDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.GraphID), self._obj.OHLC.obj_to_tuple()]
+        return (str(self._obj.GraphID), self._obj.OHLC.obj_to_tuple())
 
     def tuple_to_obj(self, t):
         if len(t) >= 2:
