@@ -9,7 +9,7 @@ class OHLCValueListDataPacker(IPacker):
         ohlc_list = []
         for o in self._obj.OHLCList:
             ohlc_list.append(o.obj_to_tuple())
-        return [ohlc_list]
+        return (ohlc_list)
 
     def tuple_to_obj(self, t):
         if len(t) >= 1:
