@@ -6,13 +6,13 @@ class PlotParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [int(self._obj.PlotIndex), int(self._obj.Height), (self._obj.IsEqValueAxis), int(self._obj.GridStyle),
+        return (int(self._obj.PlotIndex), int(self._obj.Height), (self._obj.IsEqValueAxis), int(self._obj.GridStyle),
                 str(self._obj.GridColor), str(self._obj.BackGroundColor), str(self._obj.BorderColor), int(self._obj.BorderWidth),
                 bool(self._obj.ShowLegendItem), str(self._obj.PlotName), str(self._obj.PlotNameColor), int(self._obj.GridXStyle),
-                str(self._obj.GridXColor), bool(self._obj.Visible)]
+                str(self._obj.GridXColor), bool(self._obj.Visible), bool(self._obj.ShowTitleCheck))
 
     def tuple_to_obj(self, t):
-        if len(t) >= 14:
+        if len(t) >= 15:
             self._obj.PlotIndex = t[0]
             self._obj.Height = t[1]
             self._obj.IsEqValueAxis = t[2]
@@ -27,6 +27,7 @@ class PlotParamDataPacker(IPacker):
             self._obj.GridXStyle = t[11]
             self._obj.GridXColor = t[12]
             self._obj.Visible = t[13]
+            self._obj.ShowTitleCheck = t[14]
 
             return True
         return False
