@@ -6,8 +6,8 @@ class SelectRectParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.ChartID), int(self._obj.PlotIndex), str(self._obj.ActionKey), float(self._obj.XMin),
-                float(self._obj.XMax), (self._obj.GraphParams)]
+        return (str(self._obj.ChartID), int(self._obj.PlotIndex), str(self._obj.ActionKey), float(self._obj.XMin),
+                float(self._obj.XMax), (self._obj.GraphParams))
 
     def tuple_to_obj(self, t):
         if len(t) >= 6:
