@@ -6,10 +6,10 @@ class TextGraphParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.ID), str(self._obj.Name), str(self._obj.Color), int(self._obj.PlotIndex),
+        return (str(self._obj.ID), str(self._obj.Name), str(self._obj.Color), int(self._obj.PlotIndex),
                 int(self._obj.ValueAxisID), str(self._obj.Text), float(self._obj.Key), float(self._obj.Value),
                 int(self._obj.MillTimeSpan), bool(self._obj.JoinValueAxis), bool(self._obj.ShowLegend),
-                str(self._obj.LegendFormat), str(self._obj.LegendColor), dict(self._obj.UserData), bool(self._obj.Visible)]
+                str(self._obj.LegendFormat), str(self._obj.LegendColor), dict(self._obj.UserData), bool(self._obj.Visible))
 
     def tuple_to_obj(self, t):
         if len(t) >= 15:
