@@ -6,7 +6,7 @@ class TimeAxisParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.ShowLabels), str(self._obj.Format)]
+        return (str(self._obj.ShowLabels), str(self._obj.Format))
 
     def tuple_to_obj(self, t):
         if len(t) >= 2:
