@@ -6,7 +6,7 @@ class TimeSpanGVListDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [self._obj.TimeSpanList, self._obj.GraphValueList, self._obj.OHLCValueList]
+        return (self._obj.TimeSpanList, self._obj.GraphValueList, self._obj.OHLCValueList)
 
     def tuple_to_obj(self, t):
         if len(t) >= 3:
