@@ -6,7 +6,7 @@ class FinPersistFiledDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [int(self._obj.Day), str(self._obj.Mark), int(self._obj.Offset), bytes(self._obj.Buffer)]
+        return (int(self._obj.Day), str(self._obj.Mark), int(self._obj.Offset), bytes(self._obj.Buffer))
 
     def tuple_to_obj(self, t):
         if len(t) >= 4:
