@@ -11,11 +11,12 @@ class FinPersistSaveParamDataPacker(IPacker):
         for filed in self._obj.Fileds:
             tempfileds.append(filed.obj_to_tuple())
 
-        return [str(self._obj.InstrumentID), str(self._obj.Period), tempfileds,
-                bool(self._obj.Append), bool(self._obj.Vacuum), str(self._obj.BasePath)]
+        return (str(self._obj.InstrumentID), str(self._obj.Period), tempfileds,
+                bool(self._obj.Append), bool(self._obj.Vacuum),
+                str(self._obj.BasePath), str(self._obj.TypeMark))
 
     def tuple_to_obj(self, t):
-        if len(t) >= 6:
+        if len(t) >= 7:
             self._obj.InstrumentID = t[0]
             self._obj.Period = t[1]
             for temp in t[2]:
@@ -25,6 +26,7 @@ class FinPersistSaveParamDataPacker(IPacker):
             self._obj.Append = t[3]
             self._obj.Vacuum = t[4]
             self._obj.BasePath = t[5]
+            self._obj.TypeMark = t[6]
 
             return True
         return False
