@@ -6,8 +6,8 @@ class HistoryTickParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.MarketName), str(self._obj.ExchangeID), str(self._obj.InstrumentID), str(self._obj.StartDate),
-                str(self._obj.EndDate), list(self._obj.TickList)]
+        return (str(self._obj.MarketName), str(self._obj.ExchangeID), str(self._obj.InstrumentID), str(self._obj.StartDate),
+                str(self._obj.EndDate), list(self._obj.TickList))
 
     def tuple_to_obj(self, t):
         if len(t) >= 6:
