@@ -6,7 +6,7 @@ class MarketParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.MarketNames)]
+        return tuple([str(self._obj.MarketNames)])
 
     def tuple_to_obj(self, t):
         if len(t) >= 1:
