@@ -6,10 +6,10 @@ class QueryParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.MarketName), str(self._obj.InvestorID), str(self._obj.BrokerID), str(self._obj.ExchangeID),
+        return (str(self._obj.MarketName), str(self._obj.InvestorID), str(self._obj.BrokerID), str(self._obj.ExchangeID),
                 str(self._obj.ExchangeInstID), str(self._obj.InstrumentID), int(self._obj.ProductType), str(self._obj.ProductID),
                 str(self._obj.OrderID), str(self._obj.TradeID), str(self._obj.InsertTimeStart), str(self._obj.InsertTimeEnd),
-                str(self._obj.TradeTimeStart), str(self._obj.TradeTimeEnd), str(self._obj.CurrencyID), int(self._obj.HedgeType)]
+                str(self._obj.TradeTimeStart), str(self._obj.TradeTimeEnd), str(self._obj.CurrencyID), int(self._obj.HedgeType))
 
     def tuple_to_obj(self, t):
         if len(t) >= 16:
