@@ -6,7 +6,7 @@ class SubOHLCParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.MarketName), str(self._obj.ExchangeID), str(self._obj.InstrumentID), str(self._obj.Range)]
+        return (str(self._obj.MarketName), str(self._obj.ExchangeID), str(self._obj.InstrumentID), str(self._obj.Range))
 
     def tuple_to_obj(self, t):
         if len(t) >= 4:
