@@ -1,12 +1,13 @@
 from ...interface import IPacker
+from typing import Tuple
 
 
 class InstrumentDataPacker(IPacker):
     def __init__(self, obj) -> None:
         super().__init__(obj)
 
-    def obj_to_tuple(self):
-        return [str(self._obj.InstrumentID), str(self._obj.ExchangeID), str(self._obj.InstrumentName),
+    def obj_to_tuple(self) -> Tuple:
+        return (str(self._obj.InstrumentID), str(self._obj.ExchangeID), str(self._obj.InstrumentName),
                 str(self._obj.UniCode), str(self._obj.ProductID), int(self._obj.ProductType), str(self._obj.DeliveryYear),
                 str(self._obj.DeliveryMonth), str(self._obj.CreateDate), str(self._obj.OpenDate), str(self._obj.ExpireDate),
                 str(self._obj.StartDelivDate), str(self._obj.EndDelivDate), int(self._obj.MaxMarketOrderVolume), int(self._obj.MinMarketOrderVolume),
@@ -15,9 +16,9 @@ class InstrumentDataPacker(IPacker):
                 float(self._obj.StrikePrice), int(self._obj.OptionsType), str(self._obj.UnderlyingInstrID), float(self._obj.UnderlyingMultiple),
                 int(self._obj.CombinationType), int(self._obj.StrikeModeType), float(self._obj.ObjectPrice), float(self._obj.ObjectMarginRatioByMoney),
                 float(self._obj.ObjectMarginRatioByVolume), float(self._obj.EnsureRatio1), float(self._obj.EnsureRatio2), bool(self._obj.IsCloseToday),
-                self._obj.Times]
+                self._obj.Times)
 
-    def tuple_to_obj(self, t):
+    def tuple_to_obj(self, t) -> bool:
         if len(t) >= 36:
             self._obj.InstrumentID = t[0]
             self._obj.ExchangeID = t[1]
