@@ -1,4 +1,5 @@
 from ...interface import IPacker
+from typing import Tuple
 
 
 class SaveInstrumentParamDataPacker(IPacker):
@@ -6,11 +7,12 @@ class SaveInstrumentParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [list(self._obj.DataList)]
+        return (list(self._obj.DataList), str(self._obj.BasePath))
 
     def tuple_to_obj(self, t):
-        if len(t) >= 1:
+        if len(t) >= 2:
             self._obj.DataList = t[0]
+            self._obj.BasePath = t[1]
 
             return True
         return False
