@@ -1,4 +1,5 @@
 from ...interface import IPacker
+from typing import Tuple
 
 
 class TradeParamDataPacker(IPacker):
@@ -6,7 +7,7 @@ class TradeParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.TradeNames)]
+        return tuple([str(self._obj.TradeNames)])
 
     def tuple_to_obj(self, t):
         if len(t) >= 1:
