@@ -4,15 +4,15 @@ import time
 import zlib
 import traceback
 from datetime import datetime
+from typing import Tuple
 
 from .data.message_data import MessageData
 from .interface import MsgID
 
 
 class TSocket(object):
-    __instance = None
-
     def __init__(self):
+        self.__instance_lock = threading.Lock()
         self.__HOST = '127.0.0.1'
         self.__PORT = 12321
         self.__ADDR = (self.__HOST, self.__PORT)
@@ -23,16 +23,17 @@ class TSocket(object):
         self.__CHART_CALLBACK = None
         self.__MARKET_CALLBACK = None
         self.__TRADE_CALLBACK = None
+        self.__FINDATA_CALLBACK = None
         self.__SessionInited = False
         self.__IsRunning = False
         self.__last_recv_time = -1
+        self.__is_connected = False
 
     def __del__(self):
         self.__BASE_CALLBACK = None
         self.__CHART_CALLBACK = None
         self.__MARKET_CALLBACK = None
         self.__TRADE_CALLBACK = None
-        self.close()
 
     def set_base_callback(self, base_callback):
         self.__BASE_CALLBACK = base_callback
@@ -50,24 +51,30 @@ class TSocket(object):
         self.__TRADE_CALLBACK = trade_callback
 
     def close(self):
+        self.__is_connected = False
         self.__IsRunning = False
-        if self.__TCP_SOCKET is not None:
-            self.__TCP_SOCKET.close()
-        if self.__RECV_T is not None:
-            self.__RECV_T.join()
-        self.__RECV_T = None
-        self.__TCP_SOCKET = None
+
+        with self.__instance_lock:
+            if self.__TCP_SOCKET is not None:
+                self.__TCP_SOCKET.close()
+            if self.__RECV_T is not None:
+                self.__RECV_T.join()
+            self.__RECV_T = None
+            self.__TCP_SOCKET = None
 
     def is_connected(self):
-        return self.__TCP_SOCKET is not None and self.__TCP_SOCKET._closed is False
+        return self.__TCP_SOCKET is not None and self.__is_connected is True
 
-    def connect(self, host: str = None, port: int = None, timeout: int = 30000):
+    def connect(self, host: str = '', port: int = -1, timeout: int = 30000) -> Tuple[bool, str]:
         if self.is_connected() is True:
-            return [True, '']
+            if self.__HOST == host and self.__PORT == port:
+                return (True, '')
+            else:
+                return (False, '已连接其他地址 %s:%s' % (self.__HOST, self.__PORT))
 
-        if host is not None:
+        if host != '':
             self.__HOST = host
-        if port is not None:
+        if port != -1:
             self.__PORT = port
         self.__ADDR = (self.__HOST, self.__PORT)
         try:
@@ -81,37 +88,48 @@ class TSocket(object):
         except socket.error as e:
             self.close()
             traceback.print_exc()
-            return [False, e.strerror]
+            error_msg = ''
+            if e.strerror is not None:
+                error_msg = e.strerror
+            return (False, error_msg)
 
         if self.__RECV_T is None:
             self.__IsRunning = True
             self.__RECV_T = threading.Thread(target=self.__recv_data)
             self.__RECV_T.start()
 
-        while True:
+        sleep_times = 0
+        while sleep_times < 10:
             if self.__SessionInited is True:
-                return [True, '']
+                self.__is_connected = True
+                return (True, '')
             time.sleep(0.5)
+            sleep_times = sleep_times + 1
 
-        return [True, '']
+        return (False, '会话准备超时')
 
     def send_message(self, msg: MessageData):
-        if self.is_connected() is False:
+        if self.is_connected() is False or self.__TCP_SOCKET is None:
             return False
-        if len(msg.UData) > 102400:
-            msg.CompressType = 0
-            compressed = zlib.compress(msg.UData, -1)
-            msg.UData = len(compressed).to_bytes(4, 'big') + compressed
 
-        msgp = msg.pack()
-        sendbytes = len(msgp).to_bytes(4, 'little') + msgp
+        with self.__instance_lock:
+            if len(msg.UData) > 102400:
+                msg.CompressType = 0
+                compressed = zlib.compress(msg.UData, -1)
+                msg.UData = len(compressed).to_bytes(4, 'big') + compressed
 
-        self.__TCP_SOCKET.sendall(sendbytes)
-        return True
+            msgp = msg.pack()
+            if msgp is None:
+                return False
+
+            sendbytes = len(msgp).to_bytes(4, 'little') + msgp
+            self.__TCP_SOCKET.sendall(sendbytes)
+
+            return True
 
     def __recv_data(self):
         while self.__IsRunning:
-            if self.is_connected() is False:
+            if self.__TCP_SOCKET is None:
                 break
             try:
                 recv_data = self.__TCP_SOCKET.recv(10000000)
@@ -119,10 +137,10 @@ class TSocket(object):
                 if len(recv_data) > 0:
                     self.__last_recv_time = int(datetime.now().timestamp())
             except Exception as e:
-                if self.__IsRunning is True:
-                    self.__TCP_SOCKET.close()
-                    traceback.print_exc()
-                return [False, e]
+                self.__TCP_SOCKET.close()
+                self.__is_connected = False
+                traceback.print_exc()
+                break
 
             try:
                 sz = int.from_bytes(self.__RECV_BYTES[:4], byteorder='little')
@@ -133,13 +151,14 @@ class TSocket(object):
                     sz = int.from_bytes(self.__RECV_BYTES[:4], byteorder='little')
             except Exception as e:
                 self.__TCP_SOCKET.close()
+                self.__is_connected = False
                 traceback.print_exc()
-                return [False, e]
 
             nowts = int(datetime.now().timestamp())
             if self.__last_recv_time > 0 and nowts - self.__last_recv_time > 3:
                 msg = MessageData(mid=int(MsgID.MSGID_Base_Heart.value))
-                self.send_message(msg=msg)
+                if self.__IsRunning is True:
+                    self.send_message(msg=msg)
             time.sleep(0.001)
 
     def __notify_msg(self, msg_bytes):
